(window.webpackJsonp=window.webpackJsonp||[]).push([["monaco-editor"],{367:function(o,e,n){"use strict";n.r(e);var t=n(0),i=n(2),r=n(239),a=n(1),l=n.n(a),u=n(359),d=n.n(u),s=function(o){function e(e){var n,t,i=o.call(this,e)||this;return i.onBlur=function(){var o,e,n;null===(e=(o=i.props).onBlur)||void 0===e||e.call(o,(null===(n=i.editor)||void 0===n?void 0:n.getValue())||"")},i.editorWillMount=function(o){var e,n;i.props.languageDefinition.register(),null===(n=(e=i.props).editorWillMount)||void 0===n||n.call(e,o)},i.editorDidMount=function(o,e){var n,t;i.editor=o,i.props.onSave&&o.addCommand(e.KeyMod.CtrlCmd|e.KeyCode.KEY_S,(function(){var e,n;null===(n=(e=i.props).onSave)||void 0===n||n.call(e,o.getValue())})),null===(t=(n=i.props).editorDidMount)||void 0===t||t.call(n,o,e)},null===(t=(n=i.props).initMonaco)||void 0===t||t.call(n,r),i}return Object(t.c)(e,o),e.prototype.componentWillUnmount=function(){this.props.languageDefinition.deregister()},e.prototype.render=function(){var o=Object(t.a)(Object(t.a)({},this.props),{language:this.props.languageDefinition.languageId,theme:this.props.theme.isDark?"vs-dark":"vs-light",options:Object(t.a)({wordWrap:"on",lineNumbers:"off",minimap:{enabled:!1},folding:!1,lineDecorationsWidth:5,overviewRulerBorder:!1},this.props.options)});return this.props.alwaysShowHelpText&&(o.overrideServices=Object(t.a)(Object(t.a)({},o.overrideServices),{storageService:{get:function(){},getBoolean:function(o){return"expandSuggestionDocs"===o},store:function(){},onWillSaveState:function(){},onDidChangeStorage:function(){}}})),l.a.createElement("div",{onBlur:this.onBlur},l.a.createElement(d.a,Object(t.a)({editorWillMount:this.editorWillMount,editorDidMount:this.editorDidMount},o)))},e}(a.PureComponent);e.default=Object(i.withTheme)(s)}}]);
//# sourceMappingURL=monaco-editor.js.map